@@ -14,6 +14,7 @@
 ##' @param tag_levels format to label plots, will be disable if 'labels' is not NULL
 ##' @param tag_size size of tags
 ##' @param design specification of the location of areas in the layout
+##' @param output one of 'gglist' or 'patchwork'
 ##' @return composite plot
 ##' @importFrom patchwork plot_layout
 ##' @importFrom patchwork plot_annotation
@@ -35,8 +36,11 @@ plot_list <- function(..., gglist = NULL,
                       labels = NULL,        
                       tag_levels = NULL,
                       tag_size = 14,
-                      design = NULL) {
-
+                      design = NULL, 
+                      output = "gglist") {
+    
+    output <- match.arg(output, c("gglist", "patchwork"))
+    
     gglist <- c(list(...), gglist)
     name <- names(gglist)
     
@@ -71,7 +75,40 @@ plot_list <- function(..., gglist = NULL,
             gglist[[i]] <- gglist[[i]] + labs(tag = labels[i])
         }
     }
-    
+
+    res <- gglist(gglist = gglist,
+          ncol = ncol, 
+          nrow = nrow, 
+          byrow = byrow,
+          widths = widths, 
+          heights = heights,
+          guides = guides,
+          labels = labels,        
+          tag_levels = tag_levels,
+          tag_size = tag_size,
+          design = design)        
+    if (output == 'gglist') return(res)
+    as.patchwork(res)
+}
+
+
+as.patchwork <- function(x) {
+    y = c(list(gglist=x), attr(x, 'params'))
+    do.call(plot_list2, y)
+}
+
+plot_list2 <- function(gglist = NULL,
+                      ncol = NULL, 
+                      nrow = NULL, 
+                      byrow = NULL,
+                      widths = NULL, 
+                      heights = NULL,
+                      guides = NULL,
+                      labels = NULL,        
+                      tag_levels = NULL,
+                      tag_size = 14,
+                      design = NULL) {
+
     p <- Reduce(`+`, gglist, init=plot_filler()) +
         plot_layout(ncol = ncol,
                     nrow = nrow,
@@ -127,18 +164,13 @@ gglist <- function(gglist, ...) {
     res <- gglist
     attr(res, 'params') <- list(...)
     structure(res,
-        class = "gglist")
+        class = c("gglist", "list")
+    )
 }
 
 ##' @method print gglist
 ##' @export
 print.gglist <- function(x, ...) {
-    y = c(list(gglist=x), attr(x, 'params'))
-    print(do.call(aplot::plot_list, y))
+    as.patchwork(x)
 }
 
-##' @method [[ gglist
-##' @export
-`[[.gglist` <- function(x, i, j, ...) {
-    x$gglist[[i]]
-}
